# Postman COVID-19 API Resource Center
This is a set of Postman collections that might help in the COVID-19 pandemic--click on the docs link for more information about each set of APIs, as well as a Run in Postman Button and environment so you can begin making API calls using each one.

The website for this project can be found at: https://covid-19-apis.postman.com/

## 🚀 Quick start

Requires `nvm`

```
  git clone git@github.com:postmanlabs/covid-19-apis.git
  cd covid-19-apis
  npm run nvmrc
  nvm use
  npm install
  npm run dev
```

## Contribution guidelines

We would love for you to contribute to the Postman COVID-19 API Resource Center! To contribute to this project, please read:

* The [Code of Conduct](https://www.postman.com/code-of-conduct)
* The [Contribution Guidelines](CONTRIBUTING.md)
* The "Work To Be Done" section at the bottom of this README.

**NOTE:** We have added a new Markdown linter with GitHub Actions. When making a pull request, it will run against this linter. Your changed files are required to pass linting before they will be merged. More information on this can be found in the [contribution guidelines](CONTRIBUTING.md).

Looking to contribute to the COVID-19 Testing Locations website? You can find that project within this repo. [View README](https://github.com/postmanlabs/covid-19-apis/tree/develop/src/components/TestingSites).

## Build locally
This assumes you have [git](https://git-scm.com/book/en/v2/Getting-Started-Installing-Git) and [npm](https://www.npmjs.com/get-npm) installed.
```
   $ git clone https://github.com/postmanlabs/covid-19-apis.git
   $ cd covid-19-apis
   $ npm install
   $ npm install -g gatsby-cli
   $ npm run dev
```

## COVID-19 Information
Postman Collections that make easier to pull, aggregate, and work with COVID-19 information. (New to Postman Collections? See our [Introduction to Postman Collections](https://learning.postman.com/docs/postman/collections/intro-to-collections/) documentation.)

- **Center for Disease Control (CDC)** ([Docs](https://documenter.getpostman.com/view/8854915/SzS7NkAL?version=latest)) - Twitter and YouTube API feeds for CDC, ad their RSS feeds for pulling information.
- **European Centre for Disease Prevention and Control (ECDC)** ([Docs](https://documenter.getpostman.com/view/8854915/SzS7NkAQ?version=latest)) - Twitter and YouTube API feeds for ECDC, ad their RSS feeds for pulling information.
- **World Health Organization (WHO)** ([Docs](https://documenter.getpostman.com/view/8854915/SzS7NkAS?version=latest)) -  - Twitter and YouTube API feeds for WHO, ad their RSS feeds for pulling information.

## Twitter
Postman collection specifically designed to work with the Twitter API.

- **COVID-19 Twitter Searches** [Docs](https://documenter.getpostman.com/view/8854915/SzS7NkEt?version=latest) - Twitter API search, with a handful of the common search terms added.
- **Twitter Accounts for State Government in 50 US States** [Docs](https://documenter.getpostman.com/view/8854915/SzYT5MzV?version=latest) - State government Twitter accounts for all 50 states in the United States.
- **Twitter Accounts for State Governors in 50 US States** [Docs](https://documenter.getpostman.com/view/8854915/SzYT5MzU?version=latest) - State governor Twitter accounts for all 50 states in the United States.
- **Twitter Accounts for State Health Departments in 50 US States** [Docs](https://documenter.getpostman.com/view/8854915/SzYT5MzW?version=latest) - State health department Twitter accounts for all 50 states in the United States.
- **County Health Departments for All 50 US States** [Docs](https://documenter.getpostman.com/view/8854915/SzYXVdyQ?version=latest) - A single collection with a request for each of the 50 states, pulling a listing of name, website, address, phone, email, twitter, and facebook for all county health departments.
- **Twitter Accounts for County Health Departments in all 50 US States** [Docs](https://documenter.getpostman.com/view/8854915/SzYXVdyR?version=latest) - The Twitter accounts for over 300 county health departments across 50 US States.

## Covid-19 APIs
New APIs that have emerged to specifically address the COVID-19 pandemic.

- **The COVID Tracking Project** ([Docs](https://documenter.getpostman.com/view/8854915/SzS8rjHv?version=latest)) - The COVID Tracking Project collects information from 50 US states, the District of Columbia, and 5 other US territories to provide the most comprehensive testing data we can collect for the novel coronavirus, SARS-CoV-2.
- **Covid19API** ([Docs](https://documenter.getpostman.com/view/10808728/SzS8rjbc?version=latest)) - A free API for data on the Coronavirus Access data on COVID19 through an easy API for free.
- **COVID19-Tracker-REST API** - ([Docs](https://documenter.getpostman.com/view/4074074/SzS7Pkup?version=latest)) - Provides global and country level statistics on the Coronavirus.
- **NovelCOVID API** ([Docs](https://documenter.getpostman.com/view/8854915/SzS7R6uu?version=latest)) - API for Current cases and more stuff about COVID-19 or the Novel Coronavirus Strain.
- **COVID-19 API** ([Docs](https://documenter.getpostman.com/view/8854915/SzS7R74j?version=latest)) - The COVID-19 API provides information related with the case of pneumonia associated with the COVID-19 coronavirus.
- **Coronavirus Data API** ([Docs](https://documenter.getpostman.com/view/8854915/SzS7R74n?version=latest)) - Provides global stats, country stats, full timeline, and country timeline for the coronavirus.
- **Health API - COVID-19** ([Docs](https://documenter.getpostman.com/view/8854915/SzS7R74s?version=latest)) - Global Coronavirus statistics by country and state.
- **Coronavirus Smartable** ([Docs](https://documenter.getpostman.com/view/8854915/SzS7R74q?version=latest)) - The coronavirus stats and news API offers latest and historic COVID-19 stats and news information per country or state.
- **New South Wales Coronavirus Cases** ([Docs](https://documenter.getpostman.com/view/8854915/SzS7R74r?version=latest)) - New South Wales Coronavirus disease 2019 (COVID-19) cases.
- **Finnhub COVID-19 API for US cases** ([Docs](https://documenter.getpostman.com/view/10724784/SzYW3LFa?version=latest)) - US Coronavirus disease 2019 (COVID-19) cases.
- **Elsevier API for generating research datasets** ([Docs](https://documenter.getpostman.com/view/10724784/SzYW3LUn?version=latest)) - Query large amount of datasets.
- **Coronavirus-PH API** ([Docs](https://documenter.getpostman.com/view/4314981/SzYW2fbH?version=latest)) - Philippines Coronavirus disease 2019 (COVID-19) cases.
- **COVID19-India API** ([Docs](https://documenter.getpostman.com/view/10724784/SzYXXKmA?version=latest)) - A volunteer-driven API for COVID-19 stats & patient tracing in India (Unofficial).
- **Covid India API** ([Docs](https://documenter.getpostman.com/view/5310017/SzYW4LYY?version=latest)) - REST API to track Coronavirus cases in India on state level.
- **COVID-19 Statistics API** ([Docs](https://documenter.getpostman.com/view/10724784/SzYXWz3x?version=latest)) - Based on public data by Johns Hopkins CSSE
- **COVID19 -India- API(By Adhikansh Mittal)** ([Docs](https://documenter.getpostman.com/view/5665978/SzYaVdaW?version=latest)) -  The data is used from the official website of the Ministry of Health and Family Welfare of India.[Official website]

## ScrAPIs
API possibilities opened up by scraping of COVID-19 related data and making available as APIs.

- **CDC Cases & Deaths** ([Docs](https://documenter.getpostman.com/view/8854915/SzS7NkTz?version=latest)) - Scraping the COVID-19 cases and deaths from CDC home page, converting to JSON, and saving within an environment.
- **CDC Testing** ([Docs](https://documenter.getpostman.com/view/8854915/SzS7R6gm?version=latest)) - Scraping the number of specimens tested for SARS CoV-2 by CDC labs and U.S. public health laboratories from the CDC website.

## Other APIs
Using existing 3rd party APIs to add value to the COVID-19 conversation.

- **US Digital Registry API** ([Docs](https://documenter.getpostman.com/view/8854915/SzS7NkEm?version=latest)) - An API for pulling federal government agencies and social media accounts.
- **News API** ([Docs](https://documenter.getpostman.com/view/8854915/SzS7NkEp?version=latest)) - An aggregate news APIs for pulling news across multiple news sources.

## Data API Templates
These are some collections being developed to help make the deployment of data APIs easier using common services.

- **Google Sheets to API** [Docs](https://documenter.getpostman.com/view/8854915/SzS8uRXM?version=latest) - Developing a Postman Collection that pulls data from a Google Sheet and then makes it available as an API, allowing the data to be seamlessly integrated into other websites and applications.
- **Website scraping to API** [Docs](https://documenter.getpostman.com/view/8854915/SzS8uRXM?version=latest) - Developing a Postman Collection that scrapes data from an existing website and then makes it available as an API for integration into other websites and applications
- **AWS Database to API** [Docs](https://documenter.getpostman.com/view/8854915/SzS8uRSy?version=latest) - Deploying APIs from Aurora, MySQL, PostgreSQL, and SQL Server databases using Postman.
- **Azure Database to API** [Docs](https://documenter.getpostman.com/view/8854915/SzS8uRT2?version=latest) - Deploying APIs from Cosmos DB, MySQL, PostgreSQL, and SQL Server databases using Postman.
- **Google Database to API** [Docs](https://documenter.getpostman.com/view/8854915/SzS8uRT3?version=latest) - Deploying APIs from Cloud DataStore, MySQL, PostgreSQL, and SQL Server databases using Postman.
- **Heroku Database to API** [Docs](https://documenter.getpostman.com/view/8854915/SzS8uRT4?version=latest) - Deploying APIs from PostgreSQL database using Postman.

## Proof of Concepts
These are some proof of concepts being worked on when it comes to COVID-19, showing what is possible with collections.

- **Volunteer Opportunities** ([GitHub](https://github.com/postman-data-api-templates/volunteer-opportunities)) ([Website](https://postman-data-api-templates.github.io/volunteer-opportunities/)) - An API and listing page of COVID-19 testing location across all 50 states.
- **COVID-19 Testing Locations** ([GitHub](https://github.com/covid-19-testing/locations)) ([Website](https://covid-19-testing.github.io/locations/)) - An API and listing page of COVID-19 testing location across all 50 states.

## Existing API Standards
If you are building a COVID-19 related APIs we recommend using some existing API and schema standards.

- **211 for Health and Human Services** [Docs](https://documenter.getpostman.com/view/8854915/SzS7NkKB?version=latest) - An open schema and API standard for defining health and human service organizations, locations, and services.
- **311 for Non-Emergency Requests** [Docs](https://documenter.getpostman.com/view/8854915/SzS7NkKC?version=latest) - An open schema and API standard for defining non-emergency requests.

To submit an API to add to the list, please email us at [COVID-19@postman.com)[mailto:COVID-19@postman.com] or submit a GitHub issue on this repository.

## Work To Be Done
We are tracking all submissions to be added to our list of COVID-19 resources using GitHub issues, and organizing any work to be done via the [api-tasks tag](https://github.com/postmanlabs/covid-19-apis/issues?q=is%3Aissue+is%3Aopen+label%3Aapi-tasks) -- feel free to jump in on an issue and help out. Here is a current list of tasks that need some work.
